[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# libRDChEBI

RDKit-based library implementing the chemistry-related functionality of the [ChEBI](https://www.ebi.ac.uk/chebi/) database.